/***************************************************************************
                          dauerauf.cc  -  Implementation Klasse CDauerauftrag
                             -------------------                                         
    begin                : Wed Aug 4 1999                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "formular.h"         /* Import Klasse CFormular */
#include "dauerauf.h"         /* Export des Moduls */


/* Konstruktor */
CDauerauftrag::CDauerauftrag()
{
 Betrag=-1;
 Buchungstext="";
 Quelle="";
 Ziel="";
 Intervall=-1;
 AendereAenderungsdatum(LiefereErstellungsdatum());
 AendereClassID(Dauerauftrag);
}

/* Destruktor */
CDauerauftrag::~CDauerauftrag()
{
 Betrag=0;
 Buchungstext="";
 Quelle="";
 Ziel="";
 Intervall=0;
}

/* generiert ein Objekt der Klasse CDauerauftrag und gibt Zeiger darauf zurueck */
CDokument* CDauerauftrag::Generate() const
{
 CDauerauftrag* d;
 
 d=new CDauerauftrag;
 return d;
}

/* gibt ein Objekt der Klasse CDauerauftrag wieder frei */
void CDauerauftrag::Free()
{
 if (ClassInvariant()==FALSE) return;
 
 CFormular::Free();
 Betrag=0;
 Buchungstext="";
 Quelle="";
 Ziel="";
 Intervall=0;
}

/* prueft die Klasseninvarianz des Objektes */
bool CDauerauftrag::ClassInvariant() const
{
 if ((CFormular::ClassInvariant()) &&
     (ZulaessigerKontoIdentifikator(Quelle)==TRUE) &&
     (ZulaessigerKontoIdentifikator(Ziel)==TRUE) &&
     (ZulaessigesIntervall(Intervall)==TRUE))
      return TRUE;
 else return FALSE;
}

/* kopiert in das aktuelle Objekt das Objekt src */
bool CDauerauftrag::Copy(CDokument* src)
{
 CDauerauftrag* a;

 if (src->ClassInvariant()==FALSE) return FALSE;
 a=dynamic_cast<CDauerauftrag*>(src); /* src int ein vom Typ CDauerauftrag */
 InitDauerauftrag(a->LiefereVerfasser(),a->LiefereTitel(),a->LiefereSchluessel(),a->LieferePruefzustand(),
              a->LiefereUnterschriftKundeVorhanden(),a->LiefereFormvorschrift(),
	      a->LiefereBetrag(),a->LiefereBuchungstext(),a->LiefereQuelle(),a->LiefereZiel(),a->LiefereIntervall());
 AendereErstellungsdatum(a->LiefereErstellungsdatum());
 AendereAenderungsdatum(a->LiefereAenderungsdatum());
 return TRUE;
}

/* vergleicht das Objekt mit dem Objekt src */
bool CDauerauftrag::EqualValue(CDokument* src) const
{
 CDauerauftrag* a;

 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 a=dynamic_cast<CDauerauftrag*>(src);
 if (CFormular::EqualValue(a)==FALSE) return FALSE;
 if (Betrag!=a->LiefereBetrag()) return FALSE;
 if (strcmp(Buchungstext,a->LiefereBuchungstext())!=0) return FALSE;
 if (strcmp(Quelle,a->LiefereQuelle())!=0) return FALSE;
 if (strcmp(Ziel,a->LiefereZiel())!=0) return FALSE;
 if (Intervall!=a->LiefereIntervall()) return FALSE;
 return TRUE;
}

/* initialisiert ein instanziiertes Objekt mit gegebenen Werten */
bool CDauerauftrag::InitDauerauftrag(QString NVerfasser,
                                         QString NTitel,
      	                                 QString NSchluessel,
		                         bool NGeprueft,
		                         bool NUnterschriftKundeVorhanden,
		                         QString NFormvorschrift,
			                 float NBetrag,
			                 QString NBuchungstext,
			                 QString NQuelle,
			                 QString NZiel,
			                 long NIntervall)
					
{
 if (ClassInvariant()==FALSE) return FALSE;

 InitFormular(NVerfasser,NTitel,NSchluessel,NGeprueft,
              NUnterschriftKundeVorhanden,NFormvorschrift);
 Betrag=NBetrag;
 Buchungstext=NBuchungstext;
 Quelle=NQuelle;
 Ziel=NZiel;
 Intervall=NIntervall;
 return TRUE;
}

/* gibt den abzubuchenden Betrag des Dauerauftrages zurueck */
float CDauerauftrag::LiefereBetrag() const
{
 return Betrag;
}

/* gibt den Buchungstext des Dauerauftrages zurueck */
QString CDauerauftrag::LiefereBuchungstext() const
{
 return Buchungstext;
}

/* gibt das Quellkonto des Dauerauftrages zurueck */
QString CDauerauftrag::LiefereQuelle() const
{
 return Quelle;
}

/* gibt das Zielkonto des Dauerauftrages zurueck */
QString CDauerauftrag::LiefereZiel() const
{
 return Ziel;
}

/* liefert das Intervall in denen der Dauerauftrag ausgefuehrt werden soll */
long CDauerauftrag::LiefereIntervall() const
{
 return Intervall;
}

/* prueft ob ein Kontoidentifikator zulaessig ist */
/* hier immer TRUE da nicht weiter spezifiziert */
bool CDauerauftrag::ZulaessigerKontoIdentifikator(QString src) const
{
return TRUE;
}

/* prueft ob ein Intervall gueltig sein kann */
bool CDauerauftrag::ZulaessigesIntervall(long src) const
{
 if (src==0) return FALSE;
 else return TRUE;
}

bool CDauerauftrag::readData(QDataStream* stream)
{
 Q_INT32 i;

 CFormular::readData(stream);
 *stream >> Betrag;
 *stream >> Buchungstext;
 *stream >> Quelle;
 *stream >> Ziel;
 *stream >> i; Intervall = i;
 return true;
}

bool CDauerauftrag::writeData(QDataStream* stream) const
{
 CFormular::writeData(stream);
 *stream << Betrag;
 *stream << Buchungstext;
 *stream << Quelle;
 *stream << Ziel;
 *stream << (Q_INT32)Intervall;
 return true;
}















