/***************************************************************************
                          dokudoc.cpp  -  Implementaion Klasse DokuDoc (Model)
                             -------------------                                         
    begin                : Wed Aug  4 17:32:35 MEST 1999
                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include <qmessagebox.h>
#include <qfile.h>
#include <qdatastream.h>
#include "dokudoc.h"


DokuDoc::DokuDoc(){

  b_modified = false;
  mappe_exists = false;
  name="unbenannt.map";

}

DokuDoc::~DokuDoc(){

 if (mappe_exists) delete mappe;

}

void DokuDoc::newDoc(){
 if (mappe_exists) delete mappe;
 mappe = new CDokumentenmappe;
 name = "unbenannt.map";
 b_modified = false;
 mappe_exists = true;
 emit documentChanged();
}

bool DokuDoc::save()
{
 QFile file;
 QDataStream stream;

 if (mappe_exists)
  {
   file.setName(name);
   file.open(IO_WriteOnly);
   stream.setDevice(&file);
   mappe->writeData(&stream);
   file.close();
   b_modified = false;
   emit documentSaved();
   return true;
  }
 else return false;
}

bool DokuDoc::saveAs(QString filename)
{
 if (mappe_exists)
  {
   name = filename;
   save();
   b_modified = false;
   emit documentChanged(); // filename changed
   return true;
  }
  else return false;
}
bool DokuDoc::load(QString filename){
 QFile file;
 QDataStream stream;
 bool b=true;


 if (filename.contains(".map")==0) return false; // nur *.map dateien

 if (mappe_exists) delete mappe;
 mappe = new CDokumentenmappe;
 name = filename;
 file.setName(name);
 file.open(IO_ReadOnly);
 stream.setDevice(&file);
 b = mappe->readData(&stream); if (b==false) return false;
 b_modified = false;
 mappe_exists = true;

 emit documentChanged();
 return b;
}

bool DokuDoc::close(){
 if (mappe_exists) delete mappe;
 mappe_exists = false;
 b_modified = false;
 emit documentChanged();
 return true;
}


bool DokuDoc::isModified(){
  return b_modified;
}

bool DokuDoc::mappeExists(){
  return mappe_exists;
}

QString DokuDoc::getName(){
  return name;
}

unsigned int DokuDoc::LiefereAnzahl(){
  return mappe->LiefereAnzahl();
}


// zaehlung bei 0 (= erstes dokument)
CDokument* DokuDoc::LiefereDokumentNumber(unsigned int number)
{

 CDokumentenmenge::TElement* p;
 unsigned int i;

 i = 0;
 if (mappe->LiefereAnzahl()!=0)
 {
  p = mappe->LiefereErstes();
  while (p->Objekt!=NULL)
  {
   if (i==number) return (p->Objekt);
   p=p->next;
   i++;
  }
 }
 return NULL;
}



bool DokuDoc::insertDokument(QString Verfasser, QString Titel, QString Schluessel)
{
 CDokument* dok;
 dok = new CDokument;
 bool b;

 if (mappe->SucheDokument(Schluessel)!=NULL) return false;
 dok->InitDokument(Verfasser, Titel, Schluessel);
 b = mappe->EinfuegeDokument(dok);
 b_modified = true;
 emit documentChanged();

 return b;
}

bool DokuDoc::insertVertrag(QString Verfasser, QString Titel, QString Schluessel,
                     bool UnterschriftKundeVorhanden, bool UnterschriftBankVorhanden,
                     QString Vertragsnummer, QString Vertragstext)
{
 CVertrag* ver;
 ver = new CVertrag;
 bool b;

 if (mappe->SucheDokument(Schluessel)!=NULL) return false;
 ver->InitVertrag(Verfasser, Titel, Schluessel, Vertragsnummer,
                  UnterschriftBankVorhanden, UnterschriftKundeVorhanden,
                  Vertragstext);
 b = mappe->EinfuegeDokument(ver);
 b_modified = true;
 emit documentChanged();

 return b;
}

bool DokuDoc::insertFormular(QString Verfasser, QString Titel, QString Schluessel,
                      bool Geprueft, bool UnterschriftKundeVorhanden, QString Formvorschrift)
{
 CFormular* form;
 bool b;

 if (mappe->SucheDokument(Schluessel)!=NULL) return false;
 form = new CFormular;
 form->InitFormular(Verfasser, Titel, Schluessel, Geprueft, UnterschriftKundeVorhanden, Formvorschrift);
 b = mappe->EinfuegeDokument(form);
 b_modified = true;
 emit documentChanged();

 return b;
}

bool DokuDoc::insertDauerauftrag(QString Verfasser, QString Titel, QString Schluessel,
                          bool Geprueft, bool UnterschriftKundeVorhanden, QString Formvorschrift,
                          QString Betrag, QString Intervall, QString Quelle, QString Ziel,
                          QString Buchungstext)
{
 CDauerauftrag* dau;
 float bet;
 long in;
 bool b;

 if (mappe->SucheDokument(Schluessel)!=NULL) return false;
 bet=Betrag.toFloat();
 in=Intervall.toUInt()*86400; // eingegeben wurde intervall in tagen, verlangt wird in sekunden
 dau = new CDauerauftrag;
 dau->InitDauerauftrag(Verfasser, Titel, Schluessel, Geprueft, UnterschriftKundeVorhanden,
                       Formvorschrift, bet, Buchungstext, Quelle, Ziel, in);
 b = mappe->EinfuegeDokument(dau);
 b_modified = true;
 emit documentChanged();

 return b;
}

bool DokuDoc::deleteDokument(QString Schluessel)
{
 bool b;

 b = mappe->LoescheDokument(Schluessel);
 b_modified = true;
 emit documentChanged();

 return b;
}

CDokument* DokuDoc::searchDokument(QString Schluessel)
{
 return (mappe->SucheDokument(Schluessel)->Objekt);
}





















