/***************************************************************************
                          formular.cc  -  Implementation Klasse CFormular
                             -------------------                                         
    begin                : Wed Aug 4 1999                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "dokument.h"         /* Import Klasse CDokument */
#include "formular.h"         /* Export des Moduls */

/* Konstruktor */
CFormular::CFormular()
{
 Geprueft=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Formvorschrift="";
 Aenderungsdatum=LiefereErstellungsdatum();
 AendereClassID(Formular);
}

/* Destruktor */
CFormular::~CFormular()
{
 Geprueft=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Formvorschrift="";
 Aenderungsdatum.setTime_t(0);
}

/* generiert ein Objekt des Typs CFormular und gibt einen Zeiger darauf zurueck */
CDokument* CFormular::Generate() const
{
 CFormular* f;
 
 f=new CFormular;
 return f;
}

/* zerstoert ein Formular wieder */
void CFormular::Free()
{
 if (ClassInvariant()==FALSE) return;
 CDokument::Free();
 Geprueft=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Formvorschrift="";
 Aenderungsdatum.setTime_t(0);
}

/* prueft die Klasseninvarianz des Objekts */
bool CFormular::ClassInvariant() const
{
 if ((CDokument::ClassInvariant()) &&
     (LiefereErstellungsdatum() <= Aenderungsdatum) &&
     (Aenderungsdatum <= LiefereSystemdatum()) &&
     (ZulaessigeFormvorschrift(Formvorschrift)))
      return TRUE;
 else return FALSE;
}

/* kopiert das Objekt src in das aktuelle Objekt */
bool CFormular::Copy(CDokument* src)
{
 CFormular* f;

 if (src->ClassInvariant()==FALSE) return FALSE;
 f=dynamic_cast<CFormular*>(src);
 InitFormular(f->LiefereVerfasser(),f->LiefereTitel(),f->LiefereSchluessel(),f->LieferePruefzustand(),
              f->LiefereUnterschriftKundeVorhanden(),f->LiefereFormvorschrift());
 AendereErstellungsdatum(f->LiefereErstellungsdatum());
 Aenderungsdatum=f->LiefereAenderungsdatum();
 return TRUE;
}

/* vergleicht den Inhalt zweier Formulare */
bool CFormular::EqualValue(CDokument* src) const
{
 CFormular* f;

 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;
 f=dynamic_cast<CFormular*>(src);
 if (CDokument::EqualValue(f)==FALSE) return FALSE;
 if (LieferePruefzustand()!=f->LieferePruefzustand()) return FALSE;
 if (LiefereUnterschriftKundeVorhanden()!=f->LiefereUnterschriftKundeVorhanden()) return FALSE;
 if (strcmp(LiefereFormvorschrift(),f->LiefereFormvorschrift())!=0) return FALSE;
 if (LiefereErstellungsdatum()!=f->LiefereErstellungsdatum()) return FALSE;
 if (LiefereAenderungsdatum()!=f->LiefereAenderungsdatum()) return FALSE;
 return TRUE;
}

/* initialisiert ein bestehendes Formular mit gegebenen Werten */
bool CFormular::InitFormular(QString NVerfasser,
                                 QString NTitel,
      	                         QString NSchluessel,
		                 bool NGeprueft,
		                 bool NUnterschriftKundeVorhanden,
		                 QString NFormvorschrift)
{
 /* Da Free() virtual ist, wird in InitDokument CFormular::Free() aufgerufen */
 InitDokument(NVerfasser,NTitel,NSchluessel);
 Geprueft=NGeprueft;
 UnterschriftKundeVorhanden=NUnterschriftKundeVorhanden;
 Formvorschrift=NFormvorschrift;
 Aenderungsdatum=LiefereErstellungsdatum();
 return TRUE;
}

/* gibt den Pruefzustand des Formulars zurueck */
bool CFormular::LieferePruefzustand() const
{
 return Geprueft;
}

/* aendert den Pruefzustand des Formulars */
void CFormular::AenderePruefzustand(bool NGeprueft)
{
 Geprueft=NGeprueft;
}

/* gibt zurueck ob der Kunde das Formular unterschrieben hat */
bool CFormular::LiefereUnterschriftKundeVorhanden() const
{
 return UnterschriftKundeVorhanden;
}

/* aendert die Tatsache ob der Kunde das Formular unterschrieben hat */
void CFormular::AendereUnterschriftKundeVorhanden(bool NUnterschriftKundeVorhanden)
{
 UnterschriftKundeVorhanden=NUnterschriftKundeVorhanden;
}

/* gibt die Formvorschrift des Formulars zurueck */
QString CFormular::LiefereFormvorschrift() const
{
 return Formvorschrift;
}

/* gibt zurueck wann das Formular zum letzten Mal geaendert wurde */
QDateTime  CFormular::LiefereAenderungsdatum() const
{
 return Aenderungsdatum;
}

/* setzt das Datum der letzten Aenderung des Formulars */
void CFormular::AendereAenderungsdatum(QDateTime NDatum)
{
 Aenderungsdatum=NDatum;
}

/* prueft ob die Formvorschrift zulaessig ist */
/* hier immer TRUE da nicht genauer spezifiziert */
bool CFormular::ZulaessigeFormvorschrift(QString src) const
{
 return TRUE; 
}



bool CFormular::readData(QDataStream* stream)
{
 CDokument::readData(stream);
 int i;
 *stream >> i; Geprueft = (bool)i;
 *stream >> i; UnterschriftKundeVorhanden = (bool)i;
 *stream >> Formvorschrift;
 *stream >> Aenderungsdatum;
 return true;
}

bool CFormular::writeData(QDataStream* stream) const
{
 CDokument::writeData(stream);
 *stream << (int)Geprueft;
 *stream << (int)UnterschriftKundeVorhanden;
 *stream << Formvorschrift;
 *stream << Aenderungsdatum;
 return true;
}









