/***************************************************************************
                          mappe.cc  -  Implementation Klasse CDokumentenmappe
                             -------------------                                         
    begin                : Wed Aug 4 1999                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "menge.h"     /* Import Klasse CDokumentenmenge */
#include "mappe.h"     /* Export des Moduls */


/* Konstruktor */
CDokumentenmappe::CDokumentenmappe()
{
 Dokumente = new CDokumentenmenge; //*Dokumente.Generate();
 Kundeninformation="";
 Erstellungsdatum=LiefereSystemdatum();
 Aenderungsdatum=Erstellungsdatum;
}

/* Destruktor */
CDokumentenmappe::~CDokumentenmappe()
{
 Free();
}

/* generiert eine neue Dokumentenmappe und gibt einen Zeiger darauf zurueck */
CDokumentenmappe* CDokumentenmappe::Generate()
{
 CDokumentenmappe* mappe;
 
 mappe=new CDokumentenmappe;
 return mappe;
}

/* gibt eine Dokumentenmappe wieder frei */
void CDokumentenmappe::Free()
{
 if (ClassInvariant()==FALSE) return;
 Kundeninformation="";
 Erstellungsdatum.setTime_t(0);
 Aenderungsdatum.setTime_t(0);
}

/* prueft die Klasseninvarianz des Objekts */
bool CDokumentenmappe::ClassInvariant() const
{
 if (Dokumente->ClassInvariant()==FALSE) return FALSE;
 if (Erstellungsdatum > LiefereSystemdatum()) return FALSE;
 if (Aenderungsdatum > LiefereSystemdatum()) return FALSE;
 if (Erstellungsdatum > Aenderungsdatum) return FALSE;
 if (ZulaessigeKundeninformation(Kundeninformation)==FALSE) return FALSE;
 return TRUE;
}

/* kopiert die Dokumentenmappe src in die aktuelle Dokumentenmappe */
bool CDokumentenmappe::Copy(CDokumentenmappe* src)
{
 if (src->ClassInvariant()==FALSE) return FALSE;

 Dokumente->Copy(src->Dokumente);
 Kundeninformation=src->Kundeninformation;
 Erstellungsdatum=src->Erstellungsdatum;
 Aenderungsdatum=src->Aenderungsdatum;
 return TRUE;
}

/* vergleicht zwei Dokumentenmappen miteinander */
bool CDokumentenmappe::EqualValue(CDokumentenmappe* src) const
{
 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 if (Erstellungsdatum!=src->Erstellungsdatum) return FALSE;
 if (Aenderungsdatum!=src->Aenderungsdatum) return FALSE;
 if (strcmp(Kundeninformation,src->Kundeninformation)!=0) return FALSE;
 return Dokumente->EqualValue(src->Dokumente);
}

/* liefert die Anzahl der Dokumente in der Dokumentenmappe */
unsigned int CDokumentenmappe::LiefereAnzahl() const
{
 return Dokumente->LiefereAnzahl();
}

/* gibt die Kundeninformation der Dokumentenmappe zurueck */
QString CDokumentenmappe::LiefereKundeninformation() const
{
 return Kundeninformation;
}

/* aendert die Kundeninformation der Dokumentenmappe */
void CDokumentenmappe::AendereKundeninformation(QString NInfo)
{
 if (ClassInvariant()==FALSE) return;

 Kundeninformation=NInfo;
 Aenderungsdatum=LiefereSystemdatum();
}

/* fuegt ein Dokument in die Dokumentenmappe ein */
bool CDokumentenmappe::EinfuegeDokument(CDokument* src)
{
 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 Aenderungsdatum=LiefereSystemdatum();
 return (Dokumente->EinfuegeDokument(src));
}

/* loescht ein Dokument aus der Dokumentenmappe */
bool CDokumentenmappe::LoescheDokument(QString Schluessel)
{
 if (ClassInvariant()==FALSE) return FALSE;
 return (Dokumente->LoescheDokument(Schluessel));
}

/* Sucht ein Dokument in der Dokumentenmappe heraus */
CDokumentenmenge::TElement* CDokumentenmappe::SucheDokument(QString Schluessel) const
{
 CDokumentenmenge::TElement* p;

 if (ClassInvariant()==FALSE) return NULL;
 p=(CDokumentenmenge::TElement*)Dokumente->SucheDokument(Schluessel);
 return p;
}

/* prueft ob ein Dokument in der Dokumentenmappe enthalten ist */
bool CDokumentenmappe::DokumentInMappe(QString Schluessel) const
{
 if (ClassInvariant()==FALSE) return FALSE;
 return Dokumente->DokumentInMenge(Schluessel);
}

/* gibt das Erstellungsdatum der Dokumentenmappe zurueck */
QDateTime CDokumentenmappe::LiefereErstellungsdatum() const
{
 return Erstellungsdatum;
}

/* liefert das Aenderungsdatum der Dokumentenmappe */
QDateTime CDokumentenmappe::LiefereAenderungsdatum() const
{
 return Aenderungsdatum;
}

/* prueft ob die Kundeninformation zulaessig ist */
/* hier immer TRUE da nicht genauer spezifiziert */
bool CDokumentenmappe::ZulaessigeKundeninformation(QString src) const
{
 return TRUE;
}

/* gibt das erste Element in der Dokumentenmappe zurueck */
CDokumentenmenge::TElement* CDokumentenmappe::LiefereErstes() const
{
 if (ClassInvariant()==FALSE) return NULL;
 return Dokumente->LiefereErstes();
}


bool CDokumentenmappe::readData(QDataStream* stream)
{
 bool b=true;
 *stream >> Kundeninformation;
 *stream >> Erstellungsdatum;
 *stream >> Aenderungsdatum;
 b=Dokumente->readData(stream);
 return b;
}

bool CDokumentenmappe::writeData(QDataStream* stream) const
{
 bool b=true;
 *stream << Kundeninformation;
 *stream << Erstellungsdatum;
 *stream << Aenderungsdatum;
 b=Dokumente->writeData(stream);
 return b;
}


QDateTime CDokumentenmappe::LiefereSystemdatum() const
{
 return QDateTime::currentDateTime();
}





